@@ -1,16 +1,19 @@
 # Ramz Editions Copyright (c) 2020 Copyright Holder All Rights Reserved.
 from aleat3.constructor import *
 from aleat3.applications import apps
-#from aleat3.output import colored as _colored
+
 # Alias for the object importing:
 _a = Aleatoryous
 _aleat = Aleatoryous
 _ie = InitError
+_app = apps
 
+__author__ = "Diego Ramirez (dr01191115@gmail.com) @DiddiLeija"
+__version__ = "0.1.7"
 
 
 # A short guide of the Aleatoryous Object:
-"""The Diddi's Aleatoryous Object.
+"""The Diddi's Aleatoryous Project.
 ===============================================================================================================================
 INTRODUCTION
 
@@ -69,7 +72,7 @@ Make a phone call to Castol
 The methods first_10(), first_50() and first_100() are variations of first_5(), so they work as the same:
 
 >>>dice = Aleatoryous("aleatory.dice", None)
->>>tot = dice.first_100
+>>>tot = dice.first_100()
 >>>print(tot[45])
 4
 >>>print(tot[99])
